require('TemplateLoader');

class PlayerMainHud {
	constructor() {
		this.templateLoader = new TemplateLoader();
		this.startTime = 0;
		this.endTime = 1;
		this.duration = 1;

		this.shipName = null;
		this.shipStatus = null;
		this.shipRepairButton = null;

		this.containerId = "main-container";
	}

	async attach(parent) {
		let template = await this.templateLoader.get('main');
		let container = document.getElementById(this.containerId);
		container.innerHTML = template;

		this.progress = document.getElementById("main--progress");
	}

	draw(context, delta) {
		if (!this.isProgressFinished()) {
			let progressValue = Math.ceil((new Date().getTime() - this.startTime) / this.duration * 100);
			this.progress.value = `${progressValue}`;
		}
	}

	isProgressFinished() {
		return new Date().getTime() >= this.endTime;
	}

	startProgress(durationInMs, onFinish) {
		this.duration = durationInMs;
		this.startTime = new Date().getTime();
		this.endTime = this.startTime + durationInMs;
		this.progress.value = 0;

		setTimeout(() => {
			onFinish();
		}, this.duration - 150);
	}

	hide() {
		document.getElementById(this.containerId).style.opacity = "0";
		document.getElementById(this.containerId).style.visibility = "hidden";
	}

	show() {
		document.getElementById(this.containerId).style.opacity = "1";
		document.getElementById(this.containerId).style.visibility = "visible";
	}
}
